#   Copyright (c) 2017, Pan Labs (panorbit.in).  
#   This file is licensed under the MIT License.
#   See the LICENSE file.

import sys
import os.path
sys.path.append(os.path.join(os.path.dirname(__file__), '..'))


from text_spider import parse
